@@ -26,6 +26,7 @@
 #ifndef __NEMIVER_I_DEBUGGER_H__
 #define __NEMIVER_I_DEBUGGER_H__
 
+#include <stdint.h>
 #include <vector>
 #include <string>
 #include <map>
@@ -377,18 +378,20 @@ public:
             UString qname;
             if (parent () == 0) {
                 a_qname = name ();
-                if (a_qname.raw ()[0] == '*') {
+                if (!a_qname.raw ().empty () && a_qname.raw ()[0] == '*') {
                     a_qname.erase (0, 1);
                 }
-            } else {
+            } else if (parent ()) {
                 parent ()->build_qname (qname);
                 qname.chomp ();
-                if (parent ()->name ()[0] == '*') {
+                if (parent () && parent ()->name ()[0] == '*') {
                     qname += "->" + name ();
                 } else {
                     qname += "." + name ();
                 }
                 a_qname = qname;
+            } else {
+                THROW ("should not be reached");
             }
         }
 
@@ -479,7 +482,7 @@ public:
         UString str;
         switch (a_state) {
             case NOT_STARTED:
-                str = "NO_STARTED";
+                str = "NOT_STARTED";
                 break;
             case READY:
                 str = "READY";
